@@ -10,6 +10,7 @@ import dataclasses
 import logging
 from typing import Awaitable, Callable, Union, Optional
 
+import aiohttp
 from aiohttp import web
 from aiohttp.web_urldispatcher import UrlDispatcher
 
@@ -22,6 +23,7 @@ logger = logging.getLogger(__name__)
 Handler = Callable[[web.Request], Awaitable[web.Response]]
 WsHandler = Callable[[web.Request], Awaitable[web.WebSocketResponse]]
 
+
 class NotFoundErrorAnswer(JsonableAnswer):
     @dataclasses.dataclass
     class Payload:
@@ -35,6 +37,7 @@ class NotFoundErrorAnswer(JsonableAnswer):
         super().__init__(payload=self.Payload(error, requested_path, registered_paths),
                          status=status, headers=headers, charset=charset)
 
+
 class NotFoundApplicationErrorAnswer(JsonableAnswer):
     @dataclasses.dataclass
     class Payload:
@@ -48,8 +51,9 @@ class NotFoundApplicationErrorAnswer(JsonableAnswer):
 
 
 @web.middleware
-async def error_middleware(request: web.Request, handler: Union[Handler, WsHandler], router: UrlDispatcher) \
-        -> Union[web.WebSocketResponse, web.Response]:
+async def error_middleware(
+        request: web.Request, handler: aiohttp.typedefs.Handler, router: UrlDispatcher
+) -> web.StreamResponse | Awaitable[web.StreamResponse]:
     try:
         response = await handler(request)
     except web.HTTPException as e:
